@@ -4,7 +4,6 @@
 # Created: 3/12/21
 
 import copy
-import gc
 import time
 from functools import partial
 from pathlib import Path
@@ -17,7 +16,7 @@ import tqdm
 from torch.cuda.amp import autocast
 
 from rtg import log, device
-from rtg.distrib import DistribTorch
+from rtg.distrib import dtorch
 from rtg.eval.clsmetric import ClsMetric
 from rtg.exp import TranslationExperiment
 from rtg.module import Model
@@ -27,8 +26,6 @@ from rtg.module.trainer import SteppedTrainer, TrainerState, EarlyStopper
 from rtg.registry import register, MODEL, ProblemType
 from rtg.utils import get_my_args, IO
 
-dtorch = DistribTorch.instance()
-
 
 class SentenceCompressor(nn.Module):
     """
@@ -345,12 +342,9 @@ class ClassifierTrainer(SteppedTrainer):
         self.exp: ClassificationExperiment = exp
         assert isinstance(self.core_model, TransformerClassifier), \
             f'Expected an instance of TransformerClassifier; but found {type(self.core_model)}'
-        trainer_args = self.exp.config.get('trainer', {}).get('init_args', {})
-        chunk_size = trainer_args.get('chunk_size', -1)
+        chunk_size = self.init_args.get('chunk_size', -1)
         if chunk_size > 0:
             log.warning("chunk_size not supported for this setup; it is ignored")
-        self.grad_accum_interval = trainer_args.get('grad_accum', 1)
-        assert self.grad_accum_interval > 0
 
         if self.n_gpus > 1:  # Multi GPU mode
             raise Exception(f"Please use: python -m rtg.distrib.launch -G {self.n_gpus} \n "
@@ -359,7 +353,7 @@ class ClassifierTrainer(SteppedTrainer):
         self.classifier = self.core_model.classifier
 
     def loss_func(self, scores, labels, train_mode=False, take_step=False):
-        loss = self.criterion(scores, labels, mask_pad=False).sum() / len(labels)
+        loss = self.criterion(scores, labels, normalizer=len(labels), mask_out=None)
         if train_mode:  # don't do this for validation set
             dtorch.backward(loss)
             if take_step:
@@ -386,8 +380,7 @@ class ClassifierTrainer(SteppedTrainer):
                     x_mask = (batch.x_seqs != batch.pad_val).unsqueeze(1)
                     scores = self.model(src=batch.x_seqs, src_mask=x_mask,
                                         score=self.criterion.input_type)
-                    loss = self.loss_func(scores=scores, labels=batch.ys,
-                                          train_mode=False, take_step=False)
+                    loss = self.loss_func(scores=scores, labels=batch.ys, train_mode=False, take_step=False)
 
                     total_loss += loss
                     num_batches += 1
@@ -463,7 +456,6 @@ class ClassifierTrainer(SteppedTrainer):
                  f' (from {self.start_step} steps);'
                  f' batch_size={batch_size} toks; sort_by={sort_by};')
 
-        distr = DistribTorch.instance()
         if batches <= start_batch:
             raise Exception(f'The model was already trained to {self.start_step} steps. '
                             f'Please increase the steps or clear the existing models')
@@ -472,7 +464,7 @@ class ClassifierTrainer(SteppedTrainer):
             batch_size=batch_size, steps=batches - start_batch, sort_by=sort_by, batch_first=True,
             keep_in_mem=keep_in_mem, fine_tune=fine_tune, y_is_cls=True)
         val_data = None
-        if distr.is_global_main:
+        if dtorch.is_global_main:
             val_data = self.exp.get_val_data(batch_size=max_toks, shuffle=False, batch_first=True,
                                              sort_desc=False, y_is_cls=True)
 
@@ -482,12 +474,14 @@ class ClassifierTrainer(SteppedTrainer):
 
         batch_count = -1
         stopper = None
-        early_stopped = False  # or converged
+        early_stopped_flag = self.exp.model_dir / '_EARLY_STOPPED'
+        if early_stopped_flag.exists():
+            early_stopped_flag.unlink()
         if early_stop:
             stopper = EarlyStopper(cur_step=self.start_step, **early_stop)
 
         with tqdm.tqdm(train_data, initial=start_batch, total=batches, unit='batch',
-                       dynamic_ncols=True, disable=not distr.is_global_main) as data_bar:
+                       dynamic_ncols=True, disable=not dtorch.is_global_main) as data_bar:
             for batch in data_bar:
                 batch_count += 1
                 take_step = (batch_count % self.grad_accum_interval) == 0
@@ -518,8 +512,8 @@ class ClassifierTrainer(SteppedTrainer):
                 if is_check_pt:
                     train_loss = train_state.reset()
                     log.info(
-                        f"Chkpt Train loss={train_loss:g}; Runs validation? {distr.is_global_main}")
-                    if distr.is_global_main:
+                        f"Chkpt Train loss={train_loss:g}; Runs validation? {dtorch.is_global_main}")
+                    if dtorch.is_global_main:
                         train_state.train_mode(False)
                         with torch.no_grad():
                             val_loss, val_scores = self.run_valid_epoch(val_data)
@@ -536,19 +530,21 @@ class ClassifierTrainer(SteppedTrainer):
                             if stopper.is_stop():
                                 log.info(f"Stopping at {stopper.cur_step} because {stopper.by}"
                                          f" didnt improve over {stopper.patience} checkpoints")
-                                early_stopped = True
-                                break
+                                early_stopped_flag.touch()
+
+                    dtorch.barrier()
                     unsaved_state = False
-                    gc.collect()
-                    distr.barrier()
+                    if early_stopped_flag.exists():
+                        log.info("Main process was early stopped; so stopping this worker process also")
+                        break
 
         # End of training
-        if unsaved_state and distr.is_global_main:
+        if unsaved_state and dtorch.is_global_main:
             train_loss = train_state.reset()
             train_state.train_mode(False)
             val_loss = self.run_valid_epoch(val_data)
             self.make_check_point(train_loss, val_loss=val_loss, keep_models=keep_models)
 
-        distr.barrier()
-        return early_stopped
+        dtorch.barrier()
+        return early_stopped_flag.exists()
 
