@@ -9,7 +9,7 @@ from rtg.exp import load_conf
 
 def parse_args():
     parser = argparse.ArgumentParser(prog="rtg.prep", description="prepare NMT experiment")
-    parser.add_argument("work_dir", help="Working directory", type=Path)
+    parser.add_argument("exp_dir", help="experiment directory", type=Path)
     parser.add_argument("conf_file", type=Path, nargs='?',
                         help="Config File. By default <work_dir>/conf.yml is used")
     return parser.parse_args()
@@ -17,7 +17,7 @@ def parse_args():
 
 def main():
     args = parse_args()
-    conf_file: Path = args.conf_file if args.conf_file else args.work_dir / 'conf.yml'
+    conf_file: Path = args.conf_file if args.conf_file else args.exp_dir / 'conf.yml'
     assert conf_file.exists()
     ExpFactory = TranslationExperiment
     is_big = load_conf(conf_file).get('spark', {})
@@ -32,7 +32,7 @@ def main():
         from rtg.big.exp import BigTranslationExperiment
         ExpFactory = BigTranslationExperiment
 
-    exp = ExpFactory(args.exp, config=conf_file, read_only=False)
+    exp = ExpFactory(args.exp_dir, config=conf_file, read_only=False)
     return exp.pre_process()
 
 if __name__ == '__main__':
