@@ -1,5 +1,5 @@
 
-
+from io import StringIO
 
 def sanity_check_experiment(exp, samples=True, shared_vocab=True):
     """
@@ -23,3 +23,13 @@ def sanity_check_experiment(exp, samples=True, shared_vocab=True):
     assert exp._trained_flag.exists()
     assert len(list(exp.model_dir.glob('*.pkl'))) > 0
     assert len((exp.model_dir / 'scores.tsv').read_text().splitlines()) > 0
+
+
+def run_decode(exp_dir, sentences):
+    assert isinstance(sentences, list)
+    from rtg.decode import main as decode_cli
+    buffer = StringIO()
+    decode_cli(exp_dir=exp_dir, input=[sentences], output=[buffer], skip_check=True, max_src_len=200)
+    lines = buffer.getvalue().splitlines()
+    buffer.close()
+    return lines
\ No newline at end of file
